@@ -22,7 +22,7 @@ def nginx_pkg(update=False):
 
 
 def nginx_reload():
-    """ Starts/Restarts nginx """
+    """ Starts/Reloads nginx """
 
     if not fabtools.service.is_running('nginx'):
         fabtools.service.start('nginx')
@@ -30,6 +30,15 @@ def nginx_reload():
         fabtools.service.reload('nginx')
 
 
+def nginx_restart():
+    """ Starts/Restarts nginx """
+
+    if not fabtools.service.is_running('nginx'):
+        fabtools.service.start('nginx')
+    else:
+        fabtools.service.restart('nginx')
+
+
 def web_static_files():
     """ Syncs statics files """
 
